import { Component, ComponentFactoryResolver } from '@angular/core';
import { AccountService } from '../../shared/account.service';
import { ConfirmModalComponent } from '../../modals/confirm-modal/confirm-modal.component';
import { Router } from '@angular/router';
import { AppService } from '../../shared/app.service';
import { AuthModalComponent } from '../../modals/auth-modal/auth-modal.component';
import { TranslateService } from '@ngx-translate/core';
export var NavbarComponent = (function () {
    function NavbarComponent(app, accountService, router, resolver, translateService) {
        this.app = app;
        this.accountService = accountService;
        this.router = router;
        this.resolver = resolver;
        this.translateService = translateService;
    }
    NavbarComponent.prototype.ngOnInit = function () {
        this.init();
    };
    NavbarComponent.prototype.init = function () {
        this.accountService.info();
    };
    Object.defineProperty(NavbarComponent.prototype, "account", {
        get: function () {
            return this.accountService.account;
        },
        enumerable: true,
        configurable: true
    });
    NavbarComponent.prototype.showLogoutModal = function () {
        var _this = this;
        if (this.app.modals(this.resolver).exists('loginModal') || this.app.modals(this.resolver).exists('logoutModal')) {
            return;
        }
        var confirm = this.app.modals(this.resolver).create(ConfirmModalComponent, 'logoutModal');
        confirm.title = this.translateService.instant('Logout');
        confirm.message = this.translateService.instant('Do you really want to leave?');
        confirm.onYes.subscribe(function ($event) { return _this.logout($event); });
        confirm.modal.show();
    };
    NavbarComponent.prototype.logout = function (itemModal) {
        var _this = this;
        this.accountService.logout().subscribe(function () {
            itemModal.modal.hide();
            _this.router.navigate(['/']);
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', '));
            }
        });
    };
    NavbarComponent.prototype.showLoginModal = function () {
        var _this = this;
        if (this.app.modals(this.resolver).exists('loginModal') || this.app.modals(this.resolver).exists('logoutModal')) {
            return;
        }
        var itemModal = this.app.modals(this.resolver).create(AuthModalComponent, 'loginModal');
        itemModal.title = this.translateService.instant('Authorization');
        itemModal.onLogin.subscribe(function ($event) { return _this.login($event); });
        itemModal.modal.show();
    };
    NavbarComponent.prototype.login = function (itemModal) {
        var _this = this;
        this.accountService.login(itemModal.account).subscribe(function (account) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.account.username = '';
                    itemModal.account.password = '';
                    itemModal.focus();
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    NavbarComponent.decorators = [
        { type: Component, args: [{
                    selector: 'navbar',
                    template: "\n    <!-- Fixed navbar -->\n    <nav class=\"app-navbar navbar navbar-default navbar-fixed-top\">\n    \t<div class=\"container-fluid\">\n    \t\t<div class=\"navbar-header\">\n    \t\t\t<button type=\"button\" class=\"navbar-toggle collapsed\" data-toggle=\"collapse\" data-target=\"#navbar\" aria-expanded=\"false\"\n    \t\t\t\taria-controls=\"navbar\">\n    \t\t\t\t<span class=\"sr-only\" translate>Menu</span>\n    \t\t\t\t<span class=\"icon-bar\"></span>\n    \t\t\t\t<span class=\"icon-bar\"></span>\n    \t\t\t\t<span class=\"icon-bar\"></span>\n    \t\t\t</button>\n    \t\t\t<a class=\"navbar-brand\" routerLink=\"/\" translate>Site name</a>\n    \t\t</div>\n    \t\t<div id=\"navbar\" class=\"navbar-collapse collapse\">\n    \t\t\t<ul class=\"nav navbar-nav navbar-right\">\n    \t\t\t\t<li [class.active]=\"router.isActive('/admin')\" *ngIf=\"account && account.checkRole('admin')\" class=\"app-navbar__item\"><a routerLink=\"/admin\" translate>Admin</a></li>\n    \t\t\t\t<li [class.active]=\"router.isActive('/account')\" *ngIf=\"account && account.checkPermissions(['read_accountpage'])\" class=\"app-navbar__item\"><a routerLink=\"/account\" translate>Account</a></li>\n    \t\t\t\t<li [class.active]=\"router.isActive('/themes')\" *ngIf=\"account\" class=\"app-navbar__item\"><a routerLink=\"/themes\" translate>Themes</a></li>\n    \t\t\t\t<li *ngIf=\"account\" class=\"pointer\">\n    \t\t\t\t\t<a (click)=\"showLogoutModal()\" translate>Logout</a>\n    \t\t\t\t</li>\n            <li *ngIf=\"!account\" class=\"pointer\">\n    \t\t\t\t\t<a (click)=\"showLoginModal()\" translate>Login</a>\n    \t\t\t\t</li>\n    \t\t\t</ul>\n    \t\t</div>\n    \t\t<!--/.nav-collapse -->\n    \t</div>\n    </nav>\n  ",
                    styles: ["\n\n  "],
                    entryComponents: [ConfirmModalComponent, AuthModalComponent]
                },] },
    ];
    /** @nocollapse */
    NavbarComponent.ctorParameters = function () { return [
        { type: AppService, },
        { type: AccountService, },
        { type: Router, },
        { type: ComponentFactoryResolver, },
        { type: TranslateService, },
    ]; };
    return NavbarComponent;
}());
//# sourceMappingURL=navbar.component.js.map