import { Component, Input, EventEmitter, Output, ViewChild } from '@angular/core';
export var SelectInputComponent = (function () {
    function SelectInputComponent() {
        this.inFormGroup = true;
        this.focused = false;
        this.items = [];
        this.readonly = false;
        this.name = 'select';
        this.placeholder = '';
        this.valueField = 'id';
        this.titleField = 'title';
        this.modelChange = new EventEmitter();
        this.errors = new EventEmitter();
        this.info = new EventEmitter();
    }
    SelectInputComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.errors.subscribe(function (data) {
            _this.errorsValue = data;
            var keys = Object.keys(data);
            if (keys[0] === _this.name) {
                _this.focus();
            }
        });
        this.info.subscribe(function (data) {
            _this.infoValue = data;
            var keys = Object.keys(data);
            if (keys[0] === _this.name) {
                _this.focus();
            }
        });
        this.init();
    };
    SelectInputComponent.prototype.init = function () {
        var _this = this;
        if (this.model) {
            this.value = this.getValue(this.model);
        }
        else {
            if (this.items && this.items.length > 0) {
                this.value = this.getValue(this.items[0]);
                this.updateModel();
            }
            else {
                this.value = this.getValue(null);
            }
        }
        setTimeout(function (out) {
            if (_this.focused === true) {
                _this.focus();
            }
        }, 700);
    };
    SelectInputComponent.prototype.focus = function () {
        this.inputElement.nativeElement.focus();
    };
    SelectInputComponent.prototype.getValue = function (item) {
        if (item !== null && item[this.valueField]) {
            return item[this.valueField];
        }
        else {
            return null;
        }
    };
    SelectInputComponent.prototype.getTitle = function (item) {
        if (item !== null && item[this.titleField]) {
            return item[this.titleField];
        }
        else {
            return null;
        }
    };
    SelectInputComponent.prototype.updateModel = function () {
        var _this = this;
        setTimeout(function (out) {
            var items = _this.items.filter(function (item) { return _this.getValue(item) === _this.value; });
            if (_this.items && items.length > 0) {
                _this.model = items[0];
            }
            else {
                _this.model = null;
            }
            _this.modelChange.emit(_this.model);
        }, 700);
    };
    SelectInputComponent.decorators = [
        { type: Component, args: [{
                    selector: 'select-input',
                    template: "\n    <div class=\"form-group\" [ngClass]=\"{'has-error':errorsValue && errorsValue[name]}\" *ngIf=\"inFormGroup\">\n      <label class=\"control-label\" [attr.for]=\"'input'+name\">{{title | translate}}</label>\n      <select class=\"form-control\" [attr.id]=\"'input'+name\" [attr.name]=\"'input'+name\" [attr.placeholder]=\"placeholder\" [(ngModel)]=\"value\"\n        [disabled]=\"readonly\" (change)=\"updateModel()\" #inputElement>\n        <option *ngFor=\"let item of items\" [ngValue]=\"getValue(item)\">{{getTitle(item) | translate}}</option>\n      </select>\n      <span class=\"help-block\" *ngIf=\"errorsValue && errorsValue[name]\">{{errorsValue[name].join(', ')}}</span>\n    </div>\n    <select class=\"form-control\" [attr.id]=\"'input'+name\" [attr.name]=\"'input'+name\" [attr.placeholder]=\"placeholder\" [(ngModel)]=\"value\"\n      [disabled]=\"readonly\" (change)=\"updateModel()\" *ngIf=\"!inFormGroup\" #inputElement>\n        <option *ngFor=\"let item of items\" [ngValue]=\"getValue(item)\">{{getTitle(item)}}</option>\n    </select>\n  ",
                    styles: ["\n    .select-input {\n\n    }\n  "]
                },] },
    ];
    /** @nocollapse */
    SelectInputComponent.ctorParameters = function () { return []; };
    SelectInputComponent.propDecorators = {
        'inputElement': [{ type: ViewChild, args: ['inputElement',] },],
        'inFormGroup': [{ type: Input },],
        'focused': [{ type: Input },],
        'items': [{ type: Input },],
        'readonly': [{ type: Input },],
        'name': [{ type: Input },],
        'placeholder': [{ type: Input },],
        'valueField': [{ type: Input },],
        'title': [{ type: Input },],
        'model': [{ type: Input },],
        'titleField': [{ type: Input },],
        'modelChange': [{ type: Output },],
        'errors': [{ type: Input },],
        'info': [{ type: Input },],
    };
    return SelectInputComponent;
}());
//# sourceMappingURL=select-input.component.js.map