var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { DomSanitizer } from '@angular/platform-browser';
import { Component, Input, Output, ComponentFactoryResolver, ViewChild } from '@angular/core';
import { Fontawesome } from './../../shared/models/fontawesome.model';
import { FontawesomeModalComponent } from './fontawesome-modal/fontawesome-modal.component';
import { ConfirmModalComponent } from '../../modals/confirm-modal/confirm-modal.component';
import { FontawesomesService } from '../../shared/fontawesomes.service';
import { AppService } from '../../shared/app.service';
import { AccountService } from '../../shared/account.service';
import { ResourcesGridComponent } from '../resources-grid/resources-grid.component';
import { TranslateService } from '@ngx-translate/core';
export var FontawesomesGridComponent = (function (_super) {
    __extends(FontawesomesGridComponent, _super);
    function FontawesomesGridComponent(sanitizer, fontawesomesService, accountService, app, resolver, translateService) {
        _super.call(this);
        this.sanitizer = sanitizer;
        this.fontawesomesService = fontawesomesService;
        this.accountService = accountService;
        this.app = app;
        this.resolver = resolver;
        this.translateService = translateService;
        this.titles = Fontawesome.titles;
        this.searchText = '';
        this.cachedResourcesService = fontawesomesService.createCache();
    }
    FontawesomesGridComponent.prototype.safeHtml = function (html) {
        return this.sanitizer.bypassSecurityTrustHtml(html);
    };
    Object.defineProperty(FontawesomesGridComponent.prototype, "account", {
        get: function () {
            return this.accountService.account;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FontawesomesGridComponent.prototype, "readonly", {
        get: function () {
            return !this.account.checkPermissions(['add_fontawesome', 'change_fontawesome', 'delete_fontawesome']);
        },
        enumerable: true,
        configurable: true
    });
    FontawesomesGridComponent.prototype.showCreateModal = function () {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(FontawesomeModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['add_fontawesome']);
        itemModal.text = this.translateService.instant('Create');
        itemModal.title = this.translateService.instant('Create new fontawesome');
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new Fontawesome();
        itemModal.modal.show();
        this.selectedItems = [itemModal.item];
    };
    FontawesomesGridComponent.prototype.showEditModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(FontawesomeModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['change_fontawesome']);
        itemModal.text = this.translateService.instant('Save');
        itemModal.title = this.translateService.instant('Edit fontawesome');
        if (itemModal.readonly) {
            itemModal.title = this.translateService.instant('Fontawesome info');
        }
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new Fontawesome(item);
        itemModal.modal.show();
        this.selectedItems = [itemModal.item];
    };
    FontawesomesGridComponent.prototype.showRemoveModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var confirm = this.app.modals(this.resolver).create(ConfirmModalComponent);
        confirm.size = 'md';
        confirm.title = this.translateService.instant('Remove');
        confirm.message = this.translateService.instant('Are you sure you want to remove a fontawesome?');
        confirm.onYes.subscribe(function ($event) { return _this.remove($event); });
        confirm.onClose.subscribe(function () { return _this.focus(); });
        this.selectedItems = [item];
        confirm.modal.show();
    };
    FontawesomesGridComponent.prototype.save = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.save(itemModal.item).subscribe(function (fontawesome) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.info.emit({ name: '' });
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    FontawesomesGridComponent.prototype.remove = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.remove(this.selectedItems).subscribe(function () {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    _this.focus();
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    FontawesomesGridComponent.decorators = [
        { type: Component, args: [{
                    selector: 'fontawesomes-grid',
                    template: "\n    <button class=\"pixel\" #focusElement></button>\n    <div class=\"app-grid fontawesomes-grid\" *ngIf=\"account\">\n      <div class=\"app-grid__toolbar--header\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n            <button type=\"button\" class=\"btn btn-primary\" aria-label=\"Create\" (click)=\"showCreateModal()\" *ngIf=\"account.checkPermissions(['add_fontawesome'])\">\n    \t\t\t\t\t<span class=\"fa fa-plus\"></span> {{ 'Create' | translate }}\n    \t\t\t\t</button>\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\">\n              <grid-search-panel [(searchText)]=\"searchText\" (onSearch)=\"search(true)\"></grid-search-panel>\n            </div>\n          </div>\n        </div>\n      </div>\n      <table class=\"app-grid__table table table-bordered table-hover\">\n        <thead>\n          <tr>\n            <th class=\"app-grid__table__col-icon\">{{titles.icon | translate}}</th>\n            <th class=\"app-grid__table__col-code\">{{titles.code | translate}}</th>\n            <th class=\"app-grid__table__col-class\">{{titles.class | translate}}</th>\n            <th class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_fontawesome','delete_fontawesome'])\" translate>Actions</th>\n          </tr>\n        </thead>\n        <tbody>\n          <tr *ngIf=\"statusListMessage\">\n            <td class=\"app-grid__table__col-status-message\" [attr.colspan]=\"3+account.checkPermissions(['change_fontawesome','delete_fontawesome'])?1:0\">\n              {{statusListMessage | translate}}\n            </td>\n          </tr>\n          <tr *ngFor=\"let item of items | slice:0:meta.perPage\" (click)=\"selectItem(item, $event)\" [ngClass]=\"{'info':isSelectedItem(item)}\" (dblclick)=\"showEditModal(item)\"\n            [hidden]=\"statusListMessage\">\n            <td class=\"app-grid__table__col-icon\" [innerHtml]=\"safeHtml(item.iconAsHtml)\"></td>\n            <td class=\"app-grid__table__col-code\">{{item.code}}</td>\n            <td class=\"app-grid__table__col-class\">{{item.class}}</td>\n            <td class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_fontawesome','delete_fontawesome'])\">\n              <grid-row-buttons (onEdit)=\"showEditModal(item)\" (onRemove)=\"showRemoveModal(item)\" [showEdit]=\"account.checkPermissions(['change_fontawesome'])\"\n                [showRemove]=\"account.checkPermissions(['delete_fontawesome'])\"></grid-row-buttons>\n            </td>\n            </tr>\n        </tbody>\n      </table>\n      <div class=\"app-grid__toolbar--footer\" [hidden]=\"statusListMessage\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\" *ngIf=\"meta.totalPages>1 || meta.totalResults>meta.perPage\">\n              <pagination [directionLinks]=\"false\" (pageChanged)=\"pageChanged($event)\" [boundaryLinks]=\"true\" [totalItems]=\"meta.totalResults\"\n                [rotate]=\"false\" [maxSize]=\"5\" [(ngModel)]=\"meta.curPage\" [itemsPerPage]=\"meta.perPage\" class=\"pagination-md pagination-compressed\"\n                firstText=\"&laquo;\" lastText=\"&raquo;\"></pagination>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  ",
                    styles: ["\n    .fontawesomes-grid {\n\n    }\n  "],
                    entryComponents: [FontawesomeModalComponent, ConfirmModalComponent]
                },] },
    ];
    /** @nocollapse */
    FontawesomesGridComponent.ctorParameters = function () { return [
        { type: DomSanitizer, },
        { type: FontawesomesService, },
        { type: AccountService, },
        { type: AppService, },
        { type: ComponentFactoryResolver, },
        { type: TranslateService, },
    ]; };
    FontawesomesGridComponent.propDecorators = {
        'loadAll': [{ type: Input },],
        'onSelectItems': [{ type: Output },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
    };
    return FontawesomesGridComponent;
}(ResourcesGridComponent));
//# sourceMappingURL=fontawesomes-grid.component.js.map