var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { Component, Input, Output, ComponentFactoryResolver, ViewChild } from '@angular/core';
import { GroupPermission } from './../../shared/models/group-permission.model';
import { ConfirmModalComponent } from '../../modals/confirm-modal/confirm-modal.component';
import { GroupPermissionsService } from '../../shared/group-permissions.service';
import { AppService } from '../../shared/app.service';
import { AccountService } from '../../shared/account.service';
import { PermissionsListModalComponent } from '../permissions-grid/permissions-list-modal/permissions-list-modal.component';
import { Permission } from '../../shared/models/permission.model';
import { Group } from '../../shared/models/group.model';
import { PermissionModalComponent } from '../permissions-grid/permission-modal/permission-modal.component';
import { PermissionsService } from '../../shared/permissions.service';
import { ResourcesGridComponent } from '../resources-grid/resources-grid.component';
import { TranslateService } from '@ngx-translate/core';
export var GroupPermissionsGridComponent = (function (_super) {
    __extends(GroupPermissionsGridComponent, _super);
    function GroupPermissionsGridComponent(groupPermissionsService, permissionsService, accountService, app, resolver, translateService) {
        _super.call(this);
        this.groupPermissionsService = groupPermissionsService;
        this.permissionsService = permissionsService;
        this.accountService = accountService;
        this.app = app;
        this.resolver = resolver;
        this.translateService = translateService;
        this.titles = GroupPermission.titles;
        this.groupTitles = Group.titles;
        this.permissionTitles = Permission.titles;
        this.searchText = '';
        this.cachedResourcesService = groupPermissionsService.createCache();
    }
    Object.defineProperty(GroupPermissionsGridComponent.prototype, "account", {
        get: function () {
            return this.accountService.account;
        },
        enumerable: true,
        configurable: true
    });
    GroupPermissionsGridComponent.prototype.showCreateModal = function () {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(PermissionsListModalComponent);
        itemModal.permissions.maxSelectCount = 10000;
        itemModal.account = this.accountService.account;
        itemModal.readonly = this.readonly;
        itemModal.text = this.translateService.instant('Append');
        ;
        itemModal.title = this.translateService.instant('Select permissions for append to group');
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new Permission();
        itemModal.modal.show();
        this.selectedItems = [new GroupPermission({
                id: itemModal.item.pk,
                permission: itemModal.item
            })];
    };
    GroupPermissionsGridComponent.prototype.showEditModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(PermissionModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['change_permission']) || this.readonly;
        itemModal.text = this.translateService.instant('Save');
        itemModal.title = this.translateService.instant('Edit permission');
        if (itemModal.readonly) {
            itemModal.title = this.translateService.instant('Permission info');
        }
        itemModal.onSave.subscribe(function ($event) { return _this.savePermission($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = item.permission;
        itemModal.modal.show();
    };
    GroupPermissionsGridComponent.prototype.savePermission = function (itemModal) {
        var _this = this;
        this.permissionsService.save(itemModal.item).subscribe(function (permission) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.info.emit({ name: '' });
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    GroupPermissionsGridComponent.prototype.showRemoveModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var confirm = this.app.modals(this.resolver).create(ConfirmModalComponent);
        confirm.size = 'md';
        confirm.title = this.translateService.instant('Remove');
        confirm.message = this.translateService.instant('Are you sure you want to remove a group permission?');
        confirm.onYes.subscribe(function ($event) { return _this.remove($event); });
        confirm.onClose.subscribe(function () { return _this.focus(); });
        this.selectedItems = [item];
        confirm.modal.show();
    };
    GroupPermissionsGridComponent.prototype.save = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.save(itemModal.items.map(function (item) { return new GroupPermission({
            id: item.pk,
            permission: item
        }); })).subscribe(function (groupPermission) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.info.emit({ name: '' });
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    GroupPermissionsGridComponent.prototype.remove = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.remove(this.selectedItems).subscribe(function () {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    _this.focus();
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    GroupPermissionsGridComponent.decorators = [
        { type: Component, args: [{
                    selector: 'group-permissions-grid',
                    template: "\n    <button class=\"pixel\" #focusElement></button>\n    <div class=\"app-grid group-permissions-grid\" *ngIf=\"account\">\n      <div class=\"app-grid__toolbar--header\">\n        <div class=\"row\">\n          <div class=\"col-sm-6\">\n            <h4>{{groupTitles.permissions | translate}}</h4>\n          </div>\n          <div class=\"col-sm-6\">\n            <button type=\"button\" class=\"btn btn-success pull-right\" aria-label=\"Create\" (click)=\"showCreateModal()\" *ngIf=\"account.checkPermissions(['change_group']) && !readonly\">\n    \t\t\t\t\t<span class=\"fa fa-plus\"></span> {{ 'Append' | translate }}\n    \t\t\t\t</button>\n          </div>\n        </div>\n      </div>\n      <table class=\"app-grid__table table table-bordered table-hover\">\n        <thead>\n          <tr>\n            <th class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{permissionTitles.id | translate}}</th>\n            <th class=\"app-grid__table__col-permission\">{{permissionTitles.name | translate}}</th>\n            <th class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_permission','change_group']) && !readonly\" translate>Actions</th>\n          </tr>\n        </thead>\n        <tbody>\n          <tr *ngIf=\"statusListMessage\">\n            <td class=\"app-grid__table__col-status-message\" [attr.colspan]=\"2+(account.checkPermissions(['change_permission','change_group']) && !readonly?1:0)\">\n              {{statusListMessage | translate}}\n            </td>\n          </tr>\n          <tr *ngFor=\"let item of items | slice:0:meta.perPage\" (click)=\"selectItem(item, $event)\" [ngClass]=\"{'info':isSelectedItem(item)}\"\n            (dblclick)=\"showEditModal(item)\" [hidden]=\"statusListMessage\">\n            <td class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{item.pk}}</td>\n            <td class=\"app-grid__table__col-permission\">{{item.permissionAsString}}</td>\n            <td class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_permission','change_group']) && !readonly\">\n              <grid-row-buttons (onEdit)=\"showEditModal(item)\" (onRemove)=\"showRemoveModal(item)\" [showEdit]=\"account.checkPermissions(['change_permission']) && !readonly\"\n                [showRemove]=\"account.checkPermissions(['change_group'])\"></grid-row-buttons>\n            </td>\n            </tr>\n        </tbody>\n      </table>\n      <div class=\"app-grid__toolbar--footer\" [hidden]=\"statusListMessage\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\" *ngIf=\"meta.totalPages>1 || meta.totalResults>meta.perPage\">\n              <pagination [directionLinks]=\"false\" (pageChanged)=\"pageChanged($event)\" [boundaryLinks]=\"true\" [totalItems]=\"meta.totalResults\"\n                [rotate]=\"false\" [maxSize]=\"5\" [(ngModel)]=\"meta.curPage\" [itemsPerPage]=\"meta.perPage\" class=\"pagination-md pagination-compressed\"\n                firstText=\"&laquo;\" lastText=\"&raquo;\"></pagination>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  ",
                    styles: ["\n    .group-permissions-grid {\n\n    }\n  "],
                    entryComponents: [PermissionModalComponent, PermissionsListModalComponent, ConfirmModalComponent]
                },] },
    ];
    /** @nocollapse */
    GroupPermissionsGridComponent.ctorParameters = function () { return [
        { type: GroupPermissionsService, },
        { type: PermissionsService, },
        { type: AccountService, },
        { type: AppService, },
        { type: ComponentFactoryResolver, },
        { type: TranslateService, },
    ]; };
    GroupPermissionsGridComponent.propDecorators = {
        'loadAll': [{ type: Input },],
        'onSelectItems': [{ type: Output },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
        'group': [{ type: Input },],
        'readonly': [{ type: Input },],
    };
    return GroupPermissionsGridComponent;
}(ResourcesGridComponent));
//# sourceMappingURL=group-permissions-grid.component.js.map