import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { Group } from './../../../shared/models/group.model';
import { GroupPermission } from '../../../shared/models/group-permission.model';
export var GroupModalComponent = (function () {
    function GroupModalComponent() {
        this.text = '';
        this.class = '';
        this.readonly = false;
        this.hideOnClose = true;
        this.account = null;
        this.title = '';
        this.item = new Group();
        this.titles = Group.titles;
        this.onClose = new EventEmitter();
        this.onSave = new EventEmitter();
        this.errors = new EventEmitter();
        this.info = new EventEmitter();
    }
    GroupModalComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.modal.onHidden.subscribe(function () { return _this.close(); });
        this.modal.onShown.subscribe(function () {
            _this.focus();
            _this.groupPermissions.group = _this.item;
            _this.groupPermissions.mockedItems =
                _this.item.permissions.map(function (permission) {
                    return new GroupPermission({
                        id: permission.pk,
                        permission: permission
                    });
                });
            _this.groupPermissions.search();
        });
    };
    GroupModalComponent.prototype.focus = function () {
        this.focusElement.focus();
    };
    GroupModalComponent.prototype.close = function () {
        if (this.hideOnClose && this.modal.isShown) {
            this.modal.hide();
        }
        this.onClose.emit(this);
        return false;
    };
    GroupModalComponent.prototype.save = function () {
        this.item.permissions =
            this.groupPermissions.mockedItems.map(function (groupPermission) { return groupPermission.permission; });
        this.onSave.emit(this);
        return false;
    };
    GroupModalComponent.decorators = [
        { type: Component, args: [{
                    selector: 'group-modal',
                    template: "\n    <div bsModal #modal=\"bs-modal\" class=\"modal fade group-modal\" [ngClass]=\"[class]\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\"\n      aria-hidden=\"true\">\n      <div class=\"modal-dialog modal-md\">\n        <div class=\"modal-content\">\n          <div class=\"modal-header\">\n            <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"close()\">\n                        <span aria-hidden=\"true\">&times;</span>\n                    </button>\n            <h4 class=\"modal-title\">{{title | translate}}</h4>\n          </div>\n          <form (ngSubmit)=\"save()\">\n            <div class=\"modal-body\">\n              <text-input [errors]=\"errors\" [info]=\"info\" name=\"name\" [(model)]=\"item.name\" [title]=\"titles.name\" [readonly]=\"readonly\"\n                [focused]=\"true\" #focusElement></text-input>\n                <group-permissions-grid [loadAll]=\"false\" #groupPermissions [readonly]=\"readonly\"></group-permissions-grid>\n            </div>\n            <div class=\"modal-footer\">\n              <modal-footer-buttons (onClose)=\"close()\" [readonly]=\"readonly\" [okTitle]=\"text\"></modal-footer-buttons>\n            </div>\n          </form>\n        </div>\n      </div>\n      </div>\n  ",
                    styles: ["\n    .group-modal {\n        .field-role{\n            display: block;\n        }\n    }\n  "]
                },] },
    ];
    /** @nocollapse */
    GroupModalComponent.ctorParameters = function () { return []; };
    GroupModalComponent.propDecorators = {
        'modal': [{ type: ViewChild, args: ['modal',] },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
        'groupPermissions': [{ type: ViewChild, args: ['groupPermissions',] },],
        'text': [{ type: Input },],
        'class': [{ type: Input },],
        'readonly': [{ type: Input },],
        'hideOnClose': [{ type: Input },],
        'account': [{ type: Input },],
        'title': [{ type: Input },],
        'item': [{ type: Input },],
        'titles': [{ type: Input },],
        'onClose': [{ type: Output },],
        'onSave': [{ type: Output },],
    };
    return GroupModalComponent;
}());
//# sourceMappingURL=group-modal.component.js.map