var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { Component, Input, Output, ComponentFactoryResolver, ViewChild } from '@angular/core';
import { Group } from './../../shared/models/group.model';
import { GroupModalComponent } from './group-modal/group-modal.component';
import { ConfirmModalComponent } from '../../modals/confirm-modal/confirm-modal.component';
import { GroupsService } from '../../shared/groups.service';
import { AppService } from '../../shared/app.service';
import { AccountService } from '../../shared/account.service';
import { ResourcesGridComponent } from '../resources-grid/resources-grid.component';
import { TranslateService } from '@ngx-translate/core';
export var GroupsGridComponent = (function (_super) {
    __extends(GroupsGridComponent, _super);
    function GroupsGridComponent(groupsService, accountService, app, resolver, translateService) {
        _super.call(this);
        this.groupsService = groupsService;
        this.accountService = accountService;
        this.app = app;
        this.resolver = resolver;
        this.translateService = translateService;
        this.titles = Group.titles;
        this.searchText = '';
        this.cachedResourcesService = groupsService.createCache();
    }
    Object.defineProperty(GroupsGridComponent.prototype, "account", {
        get: function () {
            return this.accountService.account;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(GroupsGridComponent.prototype, "readonly", {
        get: function () {
            return !this.account.checkPermissions(['add_group', 'change_group', 'delete_group']);
        },
        enumerable: true,
        configurable: true
    });
    GroupsGridComponent.prototype.showCreateModal = function () {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(GroupModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['add_group']);
        itemModal.text = this.translateService.instant('Create');
        itemModal.title = this.translateService.instant('Create new group');
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new Group();
        itemModal.modal.show();
        this.selectedItems = [itemModal.item];
    };
    GroupsGridComponent.prototype.showEditModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(GroupModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['change_group']);
        itemModal.text = this.translateService.instant('Save');
        itemModal.title = this.translateService.instant('Edit group');
        if (itemModal.readonly) {
            itemModal.title = this.translateService.instant('Group info');
        }
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new Group(item);
        itemModal.modal.show();
        this.selectedItems = [itemModal.item];
    };
    GroupsGridComponent.prototype.showRemoveModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var confirm = this.app.modals(this.resolver).create(ConfirmModalComponent);
        confirm.size = 'md';
        confirm.title = this.translateService.instant('Remove');
        confirm.message = this.translateService.instant('Are you sure you want to remove a group?');
        confirm.onYes.subscribe(function ($event) { return _this.remove($event); });
        confirm.onClose.subscribe(function () { return _this.focus(); });
        this.selectedItems = [item];
        confirm.modal.show();
    };
    GroupsGridComponent.prototype.save = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.save(itemModal.item).subscribe(function (group) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.info.emit({ name: '' });
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    GroupsGridComponent.prototype.remove = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.remove(this.selectedItems).subscribe(function () {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    _this.focus();
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    GroupsGridComponent.decorators = [
        { type: Component, args: [{
                    selector: 'groups-grid',
                    template: "\n    <button class=\"pixel\" #focusElement></button>\n    <div class=\"app-grid groups-grid\" *ngIf=\"account\">\n      <div class=\"app-grid__toolbar--header\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n            <button type=\"button\" class=\"btn btn-primary\" aria-label=\"Create\" (click)=\"showCreateModal()\" *ngIf=\"account.checkPermissions(['add_group'])\">\n    \t\t\t\t\t<span class=\"fa fa-plus\"></span> {{ 'Create' | translate }}\n    \t\t\t\t</button>\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\">\n              <grid-search-panel [(searchText)]=\"searchText\" (onSearch)=\"search(true)\"></grid-search-panel>\n            </div>\n          </div>\n        </div>\n      </div>\n      <table class=\"app-grid__table table table-bordered table-hover\">\n        <thead>\n          <tr>\n            <th class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{titles.id | translate}}</th>\n            <th class=\"app-grid__table__col-name\">{{titles.name | translate}}</th>\n            <th class=\"app-grid__table__col-permissions\">{{titles.permissions | translate}}</th>\n            <th class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_group','delete_group'])\" translate>Actions</th>\n          </tr>\n        </thead>\n        <tbody>\n          <tr *ngIf=\"statusListMessage\">\n            <td class=\"app-grid__table__col-status-message\" [attr.colspan]=\"3+(account.checkPermissions(['change_group','delete_group'])?1:0)\">\n              {{statusListMessage | translate}}\n            </td>\n          </tr>\n          <tr *ngFor=\"let item of items | slice:0:meta.perPage\" (click)=\"selectItem(item, $event)\" [ngClass]=\"{'info':isSelectedItem(item)}\" (dblclick)=\"showEditModal(item)\"\n            [hidden]=\"statusListMessage\">\n            <td class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{item.pk}}</td>\n            <td class=\"app-grid__table__col-name\">{{item.name}}</td>\n            <td class=\"app-grid__table__col-permissions\">{{item.permissionsAsString}}</td>\n              <td class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_group','delete_group'])\">\n              <grid-row-buttons (onEdit)=\"showEditModal(item)\" (onRemove)=\"showRemoveModal(item)\" [showEdit]=\"account.checkPermissions(['change_group'])\"\n                [showRemove]=\"account.checkPermissions(['delete_group'])\"></grid-row-buttons>\n            </td>\n          </tr>\n        </tbody>\n      </table>\n      <div class=\"app-grid__toolbar--footer\" [hidden]=\"statusListMessage\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\" *ngIf=\"meta.totalPages>1 || meta.totalResults>meta.perPage\">\n              <pagination [directionLinks]=\"false\" (pageChanged)=\"pageChanged($event)\" [boundaryLinks]=\"true\" [totalItems]=\"meta.totalResults\"\n                [rotate]=\"false\" [maxSize]=\"5\" [(ngModel)]=\"meta.curPage\" [itemsPerPage]=\"meta.perPage\" class=\"pagination-md pagination-compressed\"\n                firstText=\"&laquo;\" lastText=\"&raquo;\"></pagination>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  ",
                    styles: ["\n    .groups-grid {\n\n    }\n  "],
                    entryComponents: [GroupModalComponent, ConfirmModalComponent]
                },] },
    ];
    /** @nocollapse */
    GroupsGridComponent.ctorParameters = function () { return [
        { type: GroupsService, },
        { type: AccountService, },
        { type: AppService, },
        { type: ComponentFactoryResolver, },
        { type: TranslateService, },
    ]; };
    GroupsGridComponent.propDecorators = {
        'loadAll': [{ type: Input },],
        'onSelectItems': [{ type: Output },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
    };
    return GroupsGridComponent;
}(ResourcesGridComponent));
//# sourceMappingURL=groups-grid.component.js.map