import { Component, Input, Output, EventEmitter, ViewChild } from '@angular/core';
import { ResouceEnumStatus } from '../../shared/enums/resource.enums';
export var ResourcesGridComponent = (function () {
    function ResourcesGridComponent() {
        this.searchText = '';
        this.maxSelectCount = 1;
        this.onSelectItems = new EventEmitter();
    }
    Object.defineProperty(ResourcesGridComponent.prototype, "mockedItems", {
        get: function () {
            return this.cachedResourcesService.mockedItems;
        },
        set: function (items) {
            this.cachedResourcesService.mockedItems = items;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ResourcesGridComponent.prototype, "meta", {
        get: function () {
            return this.cachedResourcesService.meta;
        },
        enumerable: true,
        configurable: true
    });
    ResourcesGridComponent.prototype.pageChanged = function (event) {
        this.cachedResourcesService.meta.curPage = event.page;
        this.cachedResourcesService.meta.perPage = event.itemsPerPage;
        this.search();
    };
    Object.defineProperty(ResourcesGridComponent.prototype, "statusListMessage", {
        get: function () {
            if (this.cachedResourcesService.statusList === ResouceEnumStatus.Ok) {
                return '';
            }
            else {
                return this.cachedResourcesService.statusListMessage;
            }
        },
        enumerable: true,
        configurable: true
    });
    ResourcesGridComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.cachedResourcesService.items$.subscribe(function (resources) {
            _this.items = resources;
            _this.selectItem(_this.items[0], null, true);
        }, function (errors) {
            _this.items = [];
            _this.selectItem(null);
        });
        this.init();
    };
    ResourcesGridComponent.prototype.init = function () {
        this.loadAll = this.loadAll === undefined ? true : this.loadAll;
        if (this.loadAll) {
            this.search();
        }
    };
    ResourcesGridComponent.prototype.focus = function () {
        this.modalIsOpened = false;
        this.focusElement.nativeElement.focus();
    };
    ResourcesGridComponent.prototype.selectItem = function (item, event, checkFirst) {
        var _this = this;
        if (event && event.toElement.classList.contains('select-col') && this.selectedItems && this.selectedItems.length > 0) {
            if (this.selectedItems.filter(function (eachItem) { return eachItem.pk === item.pk; }).length > 0) {
                this.selectedItems = this.selectedItems.filter(function (eachItem) { return eachItem.pk !== item.pk; });
            }
            else {
                this.selectedItems.push(item);
            }
        }
        else {
            if (checkFirst === undefined || this.items.filter(function (eachItem) { return _this.selectedItems && _this.selectedItems.filter(function (selectedItem) { return selectedItem && selectedItem.pk === eachItem.pk; }).length > 0; }).length === 0) {
                this.selectedItems = [item];
            }
        }
        this.onSelectItems.emit(this.selectedItems);
    };
    ResourcesGridComponent.prototype.isSelectedItem = function (item) {
        return this.selectedItems && this.selectedItems.filter(function (i) { return i && i.pk === item.pk; }).length > 0;
    };
    ResourcesGridComponent.prototype.search = function (ignoreCache) {
        var filter = {};
        this.cachedResourcesService.ignoreCache = ignoreCache;
        this.cachedResourcesService.loadAll(this.searchText, filter);
    };
    ResourcesGridComponent.decorators = [
        { type: Component, args: [{
                    selector: 'resources-grid'
                },] },
    ];
    /** @nocollapse */
    ResourcesGridComponent.ctorParameters = function () { return []; };
    ResourcesGridComponent.propDecorators = {
        'loadAll': [{ type: Input },],
        'onSelectItems': [{ type: Output },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
        'readonly': [{ type: Input },],
    };
    return ResourcesGridComponent;
}());
//# sourceMappingURL=resources-grid.component.js.map