var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { User } from '../../shared/models/user.model';
import { Component, Input, Output, ComponentFactoryResolver, ViewChild } from '@angular/core';
import { UserGroup } from './../../shared/models/user-group.model';
import { ConfirmModalComponent } from '../../modals/confirm-modal/confirm-modal.component';
import { UserGroupsService } from '../../shared/user-groups.service';
import { AppService } from '../../shared/app.service';
import { AccountService } from '../../shared/account.service';
import { GroupsListModalComponent } from '../groups-grid/groups-list-modal/groups-list-modal.component';
import { Group } from '../../shared/models/group.model';
import { GroupModalComponent } from '../groups-grid/group-modal/group-modal.component';
import { GroupsService } from '../../shared/groups.service';
import { ResourcesGridComponent } from '../resources-grid/resources-grid.component';
import { TranslateService } from '@ngx-translate/core';
export var UserGroupsGridComponent = (function (_super) {
    __extends(UserGroupsGridComponent, _super);
    function UserGroupsGridComponent(userGroupsService, groupsService, accountService, app, resolver, translateService) {
        _super.call(this);
        this.userGroupsService = userGroupsService;
        this.groupsService = groupsService;
        this.accountService = accountService;
        this.app = app;
        this.resolver = resolver;
        this.translateService = translateService;
        this.titles = UserGroup.titles;
        this.userTitles = User.titles;
        this.groupTitles = Group.titles;
        this.cachedResourcesService = userGroupsService.createCache();
    }
    Object.defineProperty(UserGroupsGridComponent.prototype, "account", {
        get: function () {
            return this.accountService.account;
        },
        enumerable: true,
        configurable: true
    });
    UserGroupsGridComponent.prototype.showCreateModal = function () {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(GroupsListModalComponent);
        itemModal.groups.maxSelectCount = 10000;
        itemModal.account = this.accountService.account;
        itemModal.readonly = this.readonly;
        itemModal.text = this.translateService.instant('Append');
        ;
        itemModal.title = this.translateService.instant('Select groups for append to user');
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new Group();
        itemModal.modal.show();
        this.selectedItems = [new UserGroup({
                id: itemModal.item.pk,
                group: itemModal.item
            })];
    };
    UserGroupsGridComponent.prototype.showEditModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(GroupModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['change_group']) || this.readonly;
        itemModal.text = this.translateService.instant('Save');
        itemModal.title = this.translateService.instant('Edit group');
        if (itemModal.readonly) {
            itemModal.title = this.translateService.instant('Group info');
        }
        itemModal.onSave.subscribe(function ($event) { return _this.saveGroup($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = item.group;
        itemModal.modal.show();
    };
    UserGroupsGridComponent.prototype.saveGroup = function (itemModal) {
        var _this = this;
        this.groupsService.save(itemModal.item).subscribe(function (group) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.info.emit({ name: '' });
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    UserGroupsGridComponent.prototype.showRemoveModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var confirm = this.app.modals(this.resolver).create(ConfirmModalComponent);
        confirm.size = 'md';
        confirm.title = this.translateService.instant('Remove');
        confirm.message = this.translateService.instant('Are you sure you want to remove a user group?');
        confirm.onYes.subscribe(function ($event) { return _this.remove($event); });
        confirm.onClose.subscribe(function () { return _this.focus(); });
        this.selectedItems = [item];
        confirm.modal.show();
    };
    UserGroupsGridComponent.prototype.save = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.save(itemModal.items.map(function (item) { return new UserGroup({
            id: item.pk,
            group: item
        }); })).subscribe(function (userGroup) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.info.emit({ name: '' });
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    UserGroupsGridComponent.prototype.remove = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.remove(this.selectedItems).subscribe(function () {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    _this.focus();
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    UserGroupsGridComponent.decorators = [
        { type: Component, args: [{
                    selector: 'user-groups-grid',
                    template: "\n    <button class=\"pixel\" #focusElement></button>\n    <div class=\"app-grid user-groups-grid\" *ngIf=\"account\">\n      <div class=\"app-grid__toolbar--header\">\n        <div class=\"row\">\n          <div class=\"col-sm-6\">\n            <h4>{{userTitles.groups | translate}}</h4>\n          </div>\n          <div class=\"col-sm-6\">\n            <button type=\"button\" class=\"btn btn-success pull-right\" aria-label=\"Create\" (click)=\"showCreateModal()\" *ngIf=\"account.checkPermissions(['change_user']) && !readonly\">\n    \t\t\t\t\t<span class=\"fa fa-plus\"></span> {{ 'Append' | translate }}\n    \t\t\t\t</button>\n          </div>\n        </div>\n      </div>\n      <table class=\"app-grid__table table table-bordered table-hover\">\n        <thead>\n          <tr>\n            <th class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{groupTitles.id | translate}}</th>\n            <th class=\"app-grid__table__col-group\">{{groupTitles.name | translate}}</th>\n            <th class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_group','change_user']) && !readonly\" translate>Actions</th>\n          </tr>\n        </thead>\n        <tbody>\n          <tr *ngIf=\"statusListMessage\">\n            <td class=\"app-grid__table__col-status-message\" [attr.colspan]=\"2+((account.checkPermissions(['change_group','change_user']) && !readonly)?1:0)\">\n              {{statusListMessage | translate}}\n            </td>\n          </tr>\n          <tr *ngFor=\"let item of items | slice:0:meta.perPage\" (click)=\"selectItem(item, $event)\" [ngClass]=\"{'info':isSelectedItem(item)}\"\n            (dblclick)=\"showEditModal(item)\" [hidden]=\"statusListMessage\">\n            <td class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{item.pk}}</td>\n            <td class=\"app-grid__table__col-user\">{{item.groupAsString}}</td>\n            <td class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_group','change_user']) && !readonly\">\n              <grid-row-buttons (onEdit)=\"showEditModal(item)\" (onRemove)=\"showRemoveModal(item)\" [showEdit]=\"account.checkPermissions(['change_group']) && !readonly\"\n                [showRemove]=\"account.checkPermissions(['change_user'])\"></grid-row-buttons>\n            </td>\n            </tr>\n        </tbody>\n      </table>\n      <div class=\"app-grid__toolbar--footer\" [hidden]=\"statusListMessage\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\" *ngIf=\"meta.totalPages>1 || meta.totalResults>meta.perPage\">\n              <pagination [directionLinks]=\"false\" (pageChanged)=\"pageChanged($event)\" [boundaryLinks]=\"true\" [totalItems]=\"meta.totalResults\"\n                [rotate]=\"false\" [maxSize]=\"5\" [(ngModel)]=\"meta.curPage\" [itemsPerPage]=\"meta.perPage\" class=\"pagination-md pagination-compressed\"\n                firstText=\"&laquo;\" lastText=\"&raquo;\"></pagination>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  ",
                    styles: ["\n    .user-groups-grid {\n\n    }\n  "],
                    entryComponents: [GroupsListModalComponent, GroupModalComponent, ConfirmModalComponent]
                },] },
    ];
    /** @nocollapse */
    UserGroupsGridComponent.ctorParameters = function () { return [
        { type: UserGroupsService, },
        { type: GroupsService, },
        { type: AccountService, },
        { type: AppService, },
        { type: ComponentFactoryResolver, },
        { type: TranslateService, },
    ]; };
    UserGroupsGridComponent.propDecorators = {
        'user': [{ type: Input },],
        'loadAll': [{ type: Input },],
        'onSelectItems': [{ type: Output },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
        'readonly': [{ type: Input },],
    };
    return UserGroupsGridComponent;
}(ResourcesGridComponent));
//# sourceMappingURL=user-groups-grid.component.js.map