import { Component, EventEmitter, Input, Output, ViewChild } from '@angular/core';
import { User } from './../../../shared/models/user.model';
import { UserGroup } from '../../../shared/models/user-group.model';
export var UserModalComponent = (function () {
    function UserModalComponent() {
        this.text = '';
        this.class = '';
        this.readonly = false;
        this.hideOnClose = true;
        this.account = null;
        this.title = '';
        this.item = new User();
        this.titles = User.titles;
        this.onClose = new EventEmitter();
        this.onSave = new EventEmitter();
        this.errors = new EventEmitter();
        this.info = new EventEmitter();
    }
    UserModalComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.modal.onHidden.subscribe(function () { return _this.close(); });
        this.modal.onShown.subscribe(function () {
            _this.focus();
            _this.userGroups.user = _this.item;
            _this.userGroups.mockedItems =
                _this.item.groups.map(function (group) {
                    return new UserGroup({
                        id: group.pk,
                        group: group
                    });
                });
            _this.userGroups.search();
        });
    };
    UserModalComponent.prototype.focus = function () {
        this.focusElement.focus();
    };
    UserModalComponent.prototype.close = function () {
        if (this.hideOnClose && this.modal.isShown) {
            this.modal.hide();
        }
        this.onClose.emit(this);
        return false;
    };
    UserModalComponent.prototype.save = function () {
        this.item.groups =
            this.userGroups.mockedItems.map(function (userGroup) { return userGroup.group; });
        this.onSave.emit(this);
        return false;
    };
    UserModalComponent.decorators = [
        { type: Component, args: [{
                    selector: 'user-modal',
                    template: "\n    <div bsModal #modal=\"bs-modal\" class=\"modal fade user-modal\" [ngClass]=\"[class]\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\"\n      aria-hidden=\"true\">\n      <div class=\"modal-dialog modal-lg\">\n        <div class=\"modal-content\">\n          <div class=\"modal-header\">\n            <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"close()\">\n                        <span aria-hidden=\"true\">&times;</span>\n                    </button>\n            <h4 class=\"modal-title\">{{title | translate}}</h4>\n          </div>\n          <form (ngSubmit)=\"save()\">\n            <div class=\"modal-body\">\n              <div class=\"row\">\n                <div class=\"col-md-6\">\n                  <div class=\"row\">\n                    <div class=\"col-md-6\">\n                      <text-input [errors]=\"errors\" [info]=\"info\" name=\"username\" [(model)]=\"item.username\" [title]=\"titles.username\" [focused]=\"true\"\n                        [readonly]=\"readonly\" #focusElement></text-input>\n                    </div>\n                    <div class=\"col-md-6\">\n                      <text-input [errors]=\"errors\" [info]=\"info\" type=\"email\" name=\"email\" [(model)]=\"item.email\" [title]=\"titles.email\" [readonly]=\"readonly\"></text-input>\n                    </div>\n                    <div class=\"col-md-6\">\n                      <text-input [errors]=\"errors\" [info]=\"info\" type=\"password\" name=\"password\" [(model)]=\"item.password\" [title]=\"titles.password\"\n                        [readonly]=\"readonly\"></text-input>\n                    </div>\n                    <div class=\"col-md-6\">\n                      <text-input [errors]=\"errors\" [info]=\"info\" type=\"password\" name=\"rePassword\" [(model)]=\"item.rePassword\" [title]=\"titles.rePassword\"\n                        [readonly]=\"readonly\"></text-input>\n                    </div>\n                    <div class=\"col-md-6\">\n                      <text-input [errors]=\"errors\" [info]=\"info\" name=\"lastName\" [(model)]=\"item.lastName\" [title]=\"titles.lastName\" [readonly]=\"readonly\"></text-input>\n                    </div>\n                    <div class=\"col-md-6\">\n                      <text-input [errors]=\"errors\" [info]=\"info\" name=\"firstName\" [(model)]=\"item.firstName\" [title]=\"titles.firstName\" [readonly]=\"readonly\"></text-input>\n                    </div>\n                  </div>\n                </div>\n                <div class=\"col-md-6\">\n                  <checkboxes-input [errors]=\"errors\" name=\"roles\" [(models)]=\"item.roles\" [checkboxesTitles]=\"titles.rolesTitles\" [title]=\"titles.roles\"\n                    [readonly]=\"readonly\"></checkboxes-input>\n                </div>\n                <div class=\"col-md-6\">\n                  <user-groups-grid [loadAll]=\"false\" #userGroups [readonly]=\"readonly\"></user-groups-grid>\n                </div>\n              </div>\n            </div>\n            <div class=\"modal-footer\">\n              <modal-footer-buttons (onClose)=\"close()\" [readonly]=\"readonly\" [okTitle]=\"text\"></modal-footer-buttons>\n            </div>\n          </form>\n        </div>\n      </div>\n      </div>\n  ",
                    styles: ["\n    .user-modal {\n        .field-role{\n            display: block;\n        }\n    }\n  "]
                },] },
    ];
    /** @nocollapse */
    UserModalComponent.ctorParameters = function () { return []; };
    UserModalComponent.propDecorators = {
        'modal': [{ type: ViewChild, args: ['modal',] },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
        'userGroups': [{ type: ViewChild, args: ['userGroups',] },],
        'text': [{ type: Input },],
        'class': [{ type: Input },],
        'readonly': [{ type: Input },],
        'hideOnClose': [{ type: Input },],
        'account': [{ type: Input },],
        'title': [{ type: Input },],
        'item': [{ type: Input },],
        'titles': [{ type: Input },],
        'onClose': [{ type: Output },],
        'onSave': [{ type: Output },],
    };
    return UserModalComponent;
}());
//# sourceMappingURL=user-modal.component.js.map