var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { Component, Input, Output, ComponentFactoryResolver, ViewChild } from '@angular/core';
import { User } from './../../shared/models/user.model';
import { UserModalComponent } from './user-modal/user-modal.component';
import { ConfirmModalComponent } from './../../modals/confirm-modal/confirm-modal.component';
import { AccountService } from './../../shared/account.service';
import { AppService } from './../../shared/app.service';
import { UsersService } from '../../shared/users.service';
import { ResourcesGridComponent } from '../resources-grid/resources-grid.component';
import { TranslateService } from '@ngx-translate/core';
export var UsersGridComponent = (function (_super) {
    __extends(UsersGridComponent, _super);
    function UsersGridComponent(usersService, accountService, app, resolver, translateService) {
        _super.call(this);
        this.usersService = usersService;
        this.accountService = accountService;
        this.app = app;
        this.resolver = resolver;
        this.translateService = translateService;
        this.titles = User.titles;
        this.searchText = '';
        this.cachedResourcesService = usersService.createCache();
    }
    Object.defineProperty(UsersGridComponent.prototype, "account", {
        get: function () {
            return this.accountService.account;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UsersGridComponent.prototype, "readonly", {
        get: function () {
            return !this.account.checkPermissions(['add_user', 'change_user', 'delete_user']);
        },
        enumerable: true,
        configurable: true
    });
    UsersGridComponent.prototype.showCreateModal = function () {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(UserModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['add_user']);
        itemModal.text = this.translateService.instant('Create');
        itemModal.title = this.translateService.instant('Create new user');
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new User();
        itemModal.modal.show();
        this.selectedItems = [itemModal.item];
    };
    UsersGridComponent.prototype.showEditModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var itemModal = this.app.modals(this.resolver).create(UserModalComponent);
        itemModal.account = this.accountService.account;
        itemModal.readonly = !this.account.checkPermissions(['change_user']);
        itemModal.text = this.translateService.instant('Save');
        itemModal.title = this.translateService.instant('Edit user');
        if (itemModal.readonly) {
            itemModal.title = this.translateService.instant('User info');
        }
        itemModal.onSave.subscribe(function ($event) { return _this.save($event); });
        itemModal.onClose.subscribe(function () { return _this.focus(); });
        itemModal.item = new User(item);
        itemModal.modal.show();
        this.selectedItems = [itemModal.item];
    };
    UsersGridComponent.prototype.showRemoveModal = function (item) {
        var _this = this;
        if (this.modalIsOpened) {
            return;
        }
        this.modalIsOpened = true;
        var confirm = this.app.modals(this.resolver).create(ConfirmModalComponent);
        confirm.size = 'md';
        confirm.title = this.translateService.instant('Remove');
        confirm.message = this.translateService.instant('Are you sure you want to remove a user?');
        confirm.onYes.subscribe(function ($event) { return _this.remove($event); });
        confirm.onClose.subscribe(function () { return _this.focus(); });
        this.selectedItems = [item];
        confirm.modal.show();
    };
    UsersGridComponent.prototype.save = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.save(itemModal.item).subscribe(function (user) {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    itemModal.info.emit({ username: '' });
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    UsersGridComponent.prototype.remove = function (itemModal) {
        var _this = this;
        this.cachedResourcesService.remove(this.selectedItems).subscribe(function () {
            itemModal.modal.hide();
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    _this.focus();
                });
            }
            else {
                itemModal.errors.emit(errors);
            }
        });
    };
    UsersGridComponent.decorators = [
        { type: Component, args: [{
                    selector: 'users-grid',
                    template: "\n    <button class=\"pixel\" #focusElement></button>\n    <div class=\"app-grid users-grid\" *ngIf=\"account\">\n      <div class=\"app-grid__toolbar--header\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n            <button type=\"button\" class=\"btn btn-primary\" aria-label=\"Create\" (click)=\"showCreateModal()\" *ngIf=\"account.checkPermissions(['add_user'])\">\n    \t\t\t\t\t<span class=\"fa fa-plus\"></span> {{ 'Create' | translate }}\n    \t\t\t\t</button>\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\">\n              <grid-search-panel [(searchText)]=\"searchText\" (onSearch)=\"search(true)\"></grid-search-panel>\n            </div>\n          </div>\n        </div>\n      </div>\n      <table class=\"app-grid__table table table-bordered table-hover\">\n        <thead>\n          <tr>\n            <th class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{titles.id | translate}}</th>\n            <th class=\"app-grid__table__col-username\">{{titles.username | translate}}</th>\n            <th class=\"app-grid__table__col-asString\">{{titles.asString | translate}}</th>\n            <th class=\"app-grid__table__col-roles\">{{titles.roles | translate}}</th>\n            <th class=\"app-grid__table__col-groups\">{{titles.groups | translate}}</th>\n            <th class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_user','delete_user'])\" translate>Actions</th>\n          </tr>\n        </thead>\n        <tbody>\n          <tr *ngIf=\"statusListMessage\">\n            <td class=\"app-grid__table__col-status-message\" [attr.colspan]=\"5+(account.checkPermissions(['change_user','delete_user'])?1:0)\">\n              {{statusListMessage | translate}}\n            </td>\n          </tr>\n          <tr *ngFor=\"let item of items | slice:0:meta.perPage\" (click)=\"selectItem(item, $event)\" [ngClass]=\"{'info':isSelectedItem(item)}\" (dblclick)=\"showEditModal(item)\"\n            [hidden]=\"statusListMessage\">\n            <td class=\"app-grid__table__col-id\" [ngClass]=\"{'select-col':maxSelectCount>1}\">{{item.pk}}</td>\n            <td class=\"app-grid__table__col-username\">{{item.username}}</td>\n            <td class=\"app-grid__table__col-asString\">{{item.asString}}</td>\n            <td class=\"app-grid__table__col-roles\">{{item.rolesAsString}}</td>\n            <td class=\"app-grid__table__col-groups\">{{item.groupsAsString}}</td>\n            <td class=\"app-grid__table__col-action\" *ngIf=\"account.checkPermissions(['change_user','delete_user'])\">\n              <grid-row-buttons (onEdit)=\"showEditModal(item)\" (onRemove)=\"showRemoveModal(item)\" [showEdit]=\"account.checkPermissions(['change_user'])\"\n                [showRemove]=\"account.checkPermissions(['delete_user'])\"></grid-row-buttons>\n            </td>\n            </tr>\n        </tbody>\n      </table>\n      <div class=\"app-grid__toolbar--footer\" [hidden]=\"statusListMessage\">\n        <div class=\"row\">\n          <div class=\"col-md-3\">\n          </div>\n          <div class=\"col-md-9\">\n            <div class=\"pull-right\" *ngIf=\"meta.totalPages>1 || meta.totalResults>meta.perPage\">\n              <pagination [directionLinks]=\"false\" (pageChanged)=\"pageChanged($event)\" [boundaryLinks]=\"true\" [totalItems]=\"meta.totalResults\"\n                [rotate]=\"false\" [maxSize]=\"5\" [(ngModel)]=\"meta.curPage\" [itemsPerPage]=\"meta.perPage\" class=\"pagination-md pagination-compressed\"\n                firstText=\"&laquo;\" lastText=\"&raquo;\"></pagination>\n            </div>\n          </div>\n        </div>\n      </div>\n    </div>\n  ",
                    styles: ["\n    .users-grid {\n\n    }\n  "],
                    entryComponents: [UserModalComponent, ConfirmModalComponent]
                },] },
    ];
    /** @nocollapse */
    UsersGridComponent.ctorParameters = function () { return [
        { type: UsersService, },
        { type: AccountService, },
        { type: AppService, },
        { type: ComponentFactoryResolver, },
        { type: TranslateService, },
    ]; };
    UsersGridComponent.propDecorators = {
        'loadAll': [{ type: Input },],
        'onSelectItems': [{ type: Output },],
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
    };
    return UsersGridComponent;
}(ResourcesGridComponent));
//# sourceMappingURL=users-grid.component.js.map