import { Component, Input, Output, ViewChild, EventEmitter } from '@angular/core';
export var AlertModalComponent = (function () {
    function AlertModalComponent() {
        this.text = '';
        this.messageClass = 'text-danger';
        this.buttonClass = 'btn-default';
        this.hideOnClose = true;
        this.size = 'sm';
        this.title = '';
        this.hideButton = false;
        this.message = '';
        this.onClose = new EventEmitter();
    }
    AlertModalComponent.prototype.ngOnInit = function () {
        var _this = this;
        this.modal.onHidden.subscribe(function () { return _this.close(); });
        this.modal.onShown.subscribe(function () { return _this.focus(); });
        this.init();
    };
    AlertModalComponent.prototype.init = function () {
        if (this.message.length > 100) {
            this.size = 'md';
        }
        if (this.message.length > 1000) {
            this.size = 'lg';
        }
        if (!this.title) {
            this.title = this.text;
        }
    };
    AlertModalComponent.prototype.focus = function () {
        this.focusElement.nativeElement.focus();
    };
    AlertModalComponent.prototype.close = function () {
        if (this.hideOnClose && this.modal.isShown) {
            this.modal.hide();
        }
        this.onClose.emit(this);
        return false;
    };
    AlertModalComponent.decorators = [
        { type: Component, args: [{
                    selector: 'alert-modal',
                    template: "\n    <div bsModal #modal=\"bs-modal\" class=\"modal fade alert-modal\" tabindex=\"-1\" role=\"dialog\" aria-labelledby=\"mySmallModalLabel\"\n      aria-hidden=\"true\">\n      <div class=\"modal-dialog\" [ngClass]=\"['modal-'+size]\">\n        <div class=\"modal-content\">\n          <div class=\"modal-header\">\n            <button type=\"button\" class=\"close\" aria-label=\"Close\" (click)=\"close()\">\n                        <span aria-hidden=\"true\">&times;</span>\n                    </button>\n            <h4 class=\"modal-title\">{{title | translate}}</h4>\n          </div>\n          <form (ngSubmit)=\"close()\">\n            <div class=\"modal-body\" [ngClass]=\"[messageClass]\">\n              {{message | translate}}\n            </div>\n            <div class=\"modal-footer\">\n              <button type=\"submit\" #focusElement class=\"btn\" [ngClass]=\"[buttonClass]\">{{buttonText}}</button>\n            </div>\n          </form>\n        </div>\n      </div>\n    </div>\n  ",
                    styles: ["\n    .alert-modal {\n    }\n  "]
                },] },
    ];
    /** @nocollapse */
    AlertModalComponent.ctorParameters = function () { return []; };
    AlertModalComponent.propDecorators = {
        'focusElement': [{ type: ViewChild, args: ['focusElement',] },],
        'modal': [{ type: ViewChild, args: ['modal',] },],
        'text': [{ type: Input },],
        'messageClass': [{ type: Input },],
        'buttonClass': [{ type: Input },],
        'buttonText': [{ type: Input },],
        'hideOnClose': [{ type: Input },],
        'size': [{ type: Input },],
        'title': [{ type: Input },],
        'hideButton': [{ type: Input },],
        'message': [{ type: Input },],
        'onClose': [{ type: Output },],
    };
    return AlertModalComponent;
}());
//# sourceMappingURL=alert-modal.component.js.map