import { Component, EventEmitter } from '@angular/core';
import { User } from './../../../shared/models/user.model';
import { AccountService } from './../../../shared/account.service';
import { AppService } from '../../../shared/app.service';
import { TranslateService } from '@ngx-translate/core';
export var ProfileFrameComponent = (function () {
    function ProfileFrameComponent(accountService, app, translateService) {
        this.accountService = accountService;
        this.app = app;
        this.translateService = translateService;
        this.userTitles = User.titles;
        this.errors = new EventEmitter();
        this.info = new EventEmitter();
    }
    ProfileFrameComponent.prototype.ngOnInit = function () {
        this.title = this.translateService.instant(this.app.currentPageTitle) + ": " + this.translateService.instant('Profile');
    };
    Object.defineProperty(ProfileFrameComponent.prototype, "readonly", {
        get: function () {
            return !this.account.checkPermissions(['change_profile']);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ProfileFrameComponent.prototype, "account", {
        get: function () {
            return this.accountService.account;
        },
        set: function (val) {
            this.accountService.account = val;
        },
        enumerable: true,
        configurable: true
    });
    ProfileFrameComponent.prototype.update = function () {
        var _this = this;
        this.accountService.update(this.account).subscribe(function (user) {
            _this.account = user;
        }, function (errors) {
            if (errors.message) {
                _this.app.component.showErrorModal(errors.message.join(', ')).subscribe(function () {
                    _this.info.emit({ username: '' });
                });
            }
            else {
                _this.errors.emit(errors);
            }
        });
    };
    ProfileFrameComponent.decorators = [
        { type: Component, args: [{
                    selector: 'profile-frame',
                    template: "\n    <page-header [title]=\"title\"></page-header>\n    <form (ngSubmit)=\"update()\" *ngIf=\"account\">\n    \t<div class=\"form-group\">\n    \t\t<label for=\"inputUsername\">{{userTitles.username | translate}}</label>\n    \t\t<input type=\"text\" class=\"form-control\" id=\"inputUsername\" name=\"inputUsername\" placeholder=\"\" [(ngModel)]=\"account.username\"\n    \t\t\t[readonly]=\"readonly\">\n    \t</div>\n    \t<div class=\"form-group\">\n    \t\t<label for=\"inputEmail\">{{userTitles.email | translate}}</label>\n    \t\t<input type=\"text\" class=\"form-control\" id=\"inputEmail\" name=\"inputEmail\" placeholder=\"\" [(ngModel)]=\"account.email\"\n    \t\t\t[readonly]=\"readonly\">\n    \t</div>\n    \t<div class=\"form-group\">\n    \t\t<label for=\"inputPassword\">{{userTitles.password | translate}}</label>\n    \t\t<input type=\"password\" class=\"form-control\" id=\"inputPassword\" name=\"inputPassword\" placeholder=\"\" [(ngModel)]=\"account.password\"\n    \t\t\t[readonly]=\"readonly\">\n    \t</div>\n    \t<div class=\"form-group\">\n    \t\t<label for=\"inputRePassword\">{{userTitles.rePassword | translate}}</label>\n    \t\t<input type=\"password\" class=\"form-control\" id=\"inputRePassword\" name=\"inputRePassword\" placeholder=\"\" [(ngModel)]=\"account.rePassword\"\n    \t\t\t[readonly]=\"readonly\">\n    \t</div>\n    \t<div class=\"form-group\">\n    \t\t<label for=\"inputLastName\">{{userTitles.lastName | translate}}</label>\n    \t\t<input type=\"text\" class=\"form-control\" id=\"inputLastName\" name=\"inputLastName\" placeholder=\"\" [(ngModel)]=\"account.lastName\"\n    \t\t\t[readonly]=\"readonly\">\n    \t</div>\n    \t<div class=\"form-group\">\n    \t\t<label for=\"inputFirstName\">{{userTitles.firstName | translate}}</label>\n    \t\t<input type=\"text\" class=\"form-control\" id=\"inputFirstName\" name=\"inputFirstName\" placeholder=\"\" [(ngModel)]=\"account.firstName\"\n    \t\t\t[readonly]=\"readonly\">\n    \t</div>\n    \t<button type=\"submit\" class=\"btn btn-primary\" [ngClass]=\"{'hidden':readonly}\" translate>Update</button>\n    </form>\n  ",
                    styles: ["\n    .profile-frame {\n\n    }\n  "]
                },] },
    ];
    /** @nocollapse */
    ProfileFrameComponent.ctorParameters = function () { return [
        { type: AccountService, },
        { type: AppService, },
        { type: TranslateService, },
    ]; };
    return ProfileFrameComponent;
}());
//# sourceMappingURL=profile-frame.component.js.map