import { HttpService } from '../shared/http.service';
import { Injectable, EventEmitter } from '@angular/core';
import { AuthHttp } from 'angular2-jwt';
import { User } from './models/user.model';
import { Subject } from 'rxjs/Subject';
import 'rxjs/add/operator/map';
import { UtilsService } from './utils.service';
import { ResponseService } from './response.service';
export var AccountService = (function () {
    function AccountService(http, authHttp, response) {
        this.http = http;
        this.authHttp = authHttp;
        this.response = response;
        this.account$ = new Subject();
    }
    Object.defineProperty(AccountService.prototype, "account", {
        get: function () {
            return this._account;
        },
        set: function (user) {
            this._account = user;
            this.account$.next(this._account);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AccountService.prototype, "apiUrl", {
        get: function () {
            return this.response.apiUrl + "/account";
        },
        enumerable: true,
        configurable: true
    });
    AccountService.prototype.info = function () {
        var _this = this;
        var result = new EventEmitter();
        if (localStorage.getItem('token') === null) {
            this.account = null;
            return result;
        }
        this.authHttp.post(this.apiUrl + "/info", { 'token': localStorage.getItem('token') })
            .map(function (response) {
            if (response.json().token) {
                localStorage.setItem('token', response.json().token);
            }
            return new User(response.json().user);
        }).subscribe(function (user) {
            _this.account = user;
            result.emit(_this.account);
        }, function (error) {
            _this.account = null;
            result.error(UtilsService.extractError(error));
        });
        return result;
    };
    AccountService.prototype.login = function (account) {
        var _this = this;
        var result = new EventEmitter();
        this.authHttp.post(this.apiUrl + "/login", account.AsLoginUser)
            .map(function (response) {
            if (response.json().token) {
                localStorage.setItem('token', response.json().token);
            }
            return new User(response.json().user);
        }).subscribe(function (user) {
            _this.account = user;
            result.emit(_this.account);
        }, function (error) {
            _this.account = null;
            result.error(UtilsService.extractError(error));
        });
        return result;
    };
    AccountService.prototype.logout = function () {
        var _this = this;
        var result = new EventEmitter();
        localStorage.removeItem('token');
        setTimeout(function (out) {
            _this.account = null;
            result.emit({ message: 'OK' });
        }, 700);
        return result;
    };
    AccountService.prototype.update = function (account) {
        var _this = this;
        var result = new EventEmitter();
        this.http.put("" + this.apiUrl, account)
            .map(function (response) { return new User(response.json().user); }).subscribe(function (user) {
            _this.account = user;
            result.emit(_this.account);
        }, function (error) {
            result.error(UtilsService.extractError(error));
        });
        return result;
    };
    AccountService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    AccountService.ctorParameters = function () { return [
        { type: HttpService, },
        { type: AuthHttp, },
        { type: ResponseService, },
    ]; };
    return AccountService;
}());
//# sourceMappingURL=account.service.js.map