var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
import { ResourceModel } from './resource.model';
import { Group } from './group.model';
export var User = (function (_super) {
    __extends(User, _super);
    function User(obj) {
        _super.call(this, obj);
        this._cachedPermission = {};
    }
    Object.defineProperty(User.prototype, "roles", {
        get: function () {
            return { isActive: this.isActive, isStaff: this.isStaff, isSuperuser: this.isSuperuser };
        },
        set: function (roles) {
            this.isActive = roles['isActive'];
            this.isStaff = roles['isStaff'];
            this.isSuperuser = roles['isSuperuser'];
        },
        enumerable: true,
        configurable: true
    });
    User.prototype.parse = function (obj) {
        this.parseByFields(obj, User.titles, User.dateFields);
        this.groups = obj.groups && obj.groups.length ?
            obj.groups.map(function (group) { return new Group(group); }) : [];
        this.rePassword = this.password;
    };
    User.prototype.validate = function () {
        var result = {};
        var valid = true;
        if (this.password !== undefined && this.password !== this.rePassword) {
            result.rePassword = ['Password does not match the repeat password'];
            valid = false;
        }
        if (valid === true) {
            return valid;
        }
        return result;
    };
    User.prototype.format = function () {
        var result = this.formatByFields(User.titles, User.dateFields);
        result.groups = result.groups && result.groups.length ?
            result.groups.map(function (group) { return group.pk; }) : [];
        return result;
    };
    Object.defineProperty(User.prototype, "asString", {
        get: function () {
            if (this.lastName !== undefined && this.firstName !== undefined) {
                return this.lastName + " " + this.firstName;
            }
        },
        enumerable: true,
        configurable: true
    });
    User.prototype.checkRoles = function (rolesName) {
        var _this = this;
        return rolesName.filter(function (roleName) { return _this.checkRole(roleName); }).length > 0;
    };
    User.prototype.checkRole = function (roleName) {
        if (this.isActive) {
            if (roleName.toLowerCase() === 'admin' && this.isSuperuser) {
                return true;
            }
            if (roleName.toLowerCase() === 'staff' && this.isStaff) {
                return true;
            }
            if (roleName.toLowerCase() === 'user') {
                return true;
            }
        }
        else {
            return false;
        }
    };
    User.prototype.checkPermissions = function (permissionNames) {
        if (permissionNames.indexOf('admin') === -1) {
            permissionNames.push('admin');
        }
        if (this.checkRoles(permissionNames)) {
            return true;
        }
        else {
            return this.groups && this.groups.filter(function (group) {
                return group.checkPermissions(permissionNames);
            }).length > 0;
        }
    };
    Object.defineProperty(User.prototype, "rolesAsString", {
        get: function () {
            var roles = [];
            if (this.isActive) {
                if (this.isSuperuser) {
                    roles.push('Admin');
                }
                if (this.isStaff) {
                    roles.push('Staff');
                }
                roles.push('User');
            }
            return roles.reverse().join(', ');
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(User.prototype, "groupsAsString", {
        get: function () {
            if (this.groups) {
                return this.groups.map(function (group) { return group.asString; }).join(', ');
            }
            else {
                return '';
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(User.prototype, "AsLoginUser", {
        get: function () {
            return {
                username: this.username,
                password: this.password
            };
        },
        enumerable: true,
        configurable: true
    });
    User.titles = {
        id: 'Id',
        username: 'Username',
        password: 'Password',
        rePassword: 'Repeat password',
        usernameOrEmail: 'Username/Email',
        roles: 'Roles',
        rolesTitles: {
            isActive: 'User',
            isStaff: 'Staff',
            isSuperuser: 'Administrator' //translate
        },
        isSuperuser: 'Administrator',
        isStaff: 'Staff',
        isActive: 'User',
        asString: 'Full name',
        firstName: 'First name',
        lastName: 'Last name',
        email: 'Email',
        lastLogin: 'Last login',
        dateJoined: 'Date joined',
        groups: 'Groups' //translate
    };
    return User;
}(ResourceModel));
//# sourceMappingURL=user.model.js.map