import { Injectable, EventEmitter } from '@angular/core';
import 'rxjs/add/operator/map';
import { ResouceEnumStatus } from '../shared/enums/resource.enums';
import { HttpService } from './http.service';
import { ResponseService } from './response.service';
import { UtilsService } from '../shared/utils.service';
import { MetaModel } from '../shared/models/meta.model';
import * as _ from 'lodash';
export var ResourceService = (function () {
    function ResourceService(http, response) {
        this.http = http;
        this.response = response;
        this.props = null;
        this.items = [];
        this.mockedItems = null;
        this.cached = [];
        this.meta = new MetaModel();
        this.meta.curPage = 1;
        this.parent = null;
    }
    ResourceService.prototype.newCache = function () {
        return new ResourceService(this.http, this.response);
    };
    ResourceService.prototype.createCache = function () {
        var cache = this.newCache();
        cache.parent = this;
        this.cached.push(cache);
        return cache;
    };
    ResourceService.prototype.getFromCachedItems = function (filter) {
        if (this.parent !== null) {
            return this.parent.getFromCachedItems(filter);
        }
        else {
            for (var i = 0; i < this.cached.length; i++) {
                console.log(this.resourcesName, filter, this.cached[i].queryProps);
                if (_.isEqual(filter, this.cached[i].queryProps) && this.cached[i].items.length > 0) {
                    return this.cached[i].items;
                }
            }
        }
        console.log(this.resourcesName, filter, this.queryProps);
        if (_.isEqual(filter, this.queryProps) && this.items.length > 0) {
            return this.items;
        }
        return null;
    };
    ResourceService.prototype.calcMeta = function (totalResults) {
        this.meta.totalResults = totalResults;
        this.meta.totalPages = Math.round(totalResults / this.meta.perPage);
    };
    Object.defineProperty(ResourceService.prototype, "statusList", {
        get: function () {
            return this._statusList;
        },
        enumerable: true,
        configurable: true
    });
    ResourceService.prototype.setStatusList = function (status, message) {
        var _this = this;
        setTimeout(function (out) {
            _this._statusList = status;
            if (message) {
                _this.statusListMessage = message;
            }
            else {
                _this.statusListMessage = '';
            }
        });
    };
    Object.defineProperty(ResourceService.prototype, "statusItem", {
        get: function () {
            return this._statusItem;
        },
        enumerable: true,
        configurable: true
    });
    ResourceService.prototype.setStatusItem = function (status, message) {
        var _this = this;
        setTimeout(function (out) {
            _this._statusItem = status;
            if (message) {
                _this.statusItemMessage = message;
            }
            else {
                _this.statusItemMessage = '';
            }
        });
    };
    ResourceService.prototype.transformModel = function (item) {
        return item;
    };
    ResourceService.prototype.loadAllItems = function (loadedItems) {
        this.items = loadedItems;
        this.items$.next(this.items);
    };
    ResourceService.prototype.loadAll = function (q, filter) {
        var _this = this;
        if (q === undefined) {
            q = '';
        }
        if (filter === undefined) {
            filter = this.queryProps;
        }
        if (filter === undefined) {
            filter = {};
        }
        if (!filter.q) {
            filter.q = !q ? '' : q;
        }
        if (this.mockedItems !== null) {
            return this.mockLoadAll(filter, this.mockedItems);
        }
        var result = new EventEmitter();
        if (!filter.curPage && this.meta.curPage) {
            filter.curPage = this.meta.curPage;
        }
        if (!filter.perPage && this.meta.perPage) {
            filter.perPage = this.meta.perPage;
        }
        /* TODO: move cache to http service, current cash use for local update items cloned from root service
        if (!this.ignoreCache) {
          let cachedItems = this.getFromCachedItems(filter);
          if (cachedItems !== null) {
            return this.cacheLoadAll(cachedItems);
          }
        }
        this.ignoreCache = false;
        */
        this.queryProps = _.cloneDeep(filter);
        this.setStatusList(ResouceEnumStatus.Search, 'Searching...' //translate
        );
        this.http.get(this.response.getResourcesListUrl(this))
            .map(function (response) { return _this.response.getResourcesListResponse(_this, response).map(function (item) { return _this.transformModel(item); }); })
            .subscribe(function (loadedItems) {
            _this.loadAllItems(loadedItems);
            if (_this.items.length > 0) {
                result.emit(_this.items);
                _this.setStatusList(ResouceEnumStatus.Ok);
            }
            else {
                result.error(_this.items);
                _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                );
            }
        }, function (error) {
            if (error.json && error.json().detail === 'Invalid page.' && filter.curPage > 1) {
                filter.curPage = 1;
                _this.ignoreCache = true;
                _this.loadAll(q, filter);
            }
            else {
                _this.items$.next([]);
                result.error(UtilsService.extractError(error));
                _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                );
            }
        });
        return result;
    };
    ResourceService.prototype.mockLoadAll = function (filter, mockedItems) {
        var _this = this;
        var result = new EventEmitter();
        this.setStatusList(ResouceEnumStatus.Search, 'Searching...' //translate
        );
        setTimeout(function (out) {
            var constItems = mockedItems.filter(function (item) { return UtilsService.inValues(item, filter.q); }).map(function (item) { return _this.transformModel(item); });
            _this.calcMeta(constItems.length);
            var count = 0;
            if (_this.meta.perPage === undefined) {
                console.error('Error, you not set perPage count' //translate
                );
            }
            var startIndex = ((_this.meta.curPage <= 1 ? 0 : _this.meta.curPage - 1) * _this.meta.perPage) + 1;
            var items = constItems.filter(function (item, index) {
                if (index + 1 >= startIndex && count < _this.meta.perPage) {
                    count++;
                    return true;
                }
                else {
                    return false;
                }
                ;
            });
            _this.loadAllItems(items);
            if (_this.items.length > 0) {
                result.emit(_this.items);
                _this.setStatusList(ResouceEnumStatus.Ok);
            }
            else {
                result.error(_this.items);
                _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                );
            }
        });
        return result;
    };
    ResourceService.prototype.cacheLoadAll = function (cachedItems) {
        var _this = this;
        var result = new EventEmitter();
        this.setStatusList(ResouceEnumStatus.Search, 'Searching...' //translate
        );
        setTimeout(function (out) {
            _this.loadAllItems(cachedItems);
            if (_this.items.length > 0) {
                result.emit(_this.items);
                _this.setStatusList(ResouceEnumStatus.Ok);
            }
            else {
                result.error(_this.items);
                _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                );
            }
        });
        return result;
    };
    ResourceService.prototype.loadItem = function (loadedItem) {
        var _this = this;
        var notFound = true;
        this.items.forEach(function (item, index) {
            if (item.pk === loadedItem.pk) {
                _this.items[index] = loadedItem;
                notFound = false;
            }
        });
        if (notFound) {
            this.items.push(loadedItem);
        }
        this.items$.next(this.items);
    };
    ResourceService.prototype.load = function (key) {
        var _this = this;
        var result = new EventEmitter();
        this.setStatusItem(ResouceEnumStatus.Loading, 'Loading...' //translate
        );
        this.http.get(this.response.getResourceItemUrl(this, key)).map(function (response) { return _this.transformModel(_this.response.getResourceItemResponse(_this, response)); })
            .subscribe(function (loadedItem) {
            _this.loadItem(loadedItem);
            result.emit(loadedItem);
            _this.setStatusItem(ResouceEnumStatus.Ok);
        }, function (error) {
            result.error(UtilsService.extractError(error));
            _this.setStatusItem(ResouceEnumStatus.NotFound, 'Not found' //translate
            );
        });
        return result;
    };
    ResourceService.prototype.createItem = function (createdItem) {
        this.calcMeta(this.meta.totalResults + 1);
        if (this.mockedItems !== null) {
            this.mockedItems.unshift(createdItem);
        }
        this.items.unshift(createdItem);
        this.items$.next(this.items);
    };
    ResourceService.prototype.create = function (item) {
        var _this = this;
        var result = new EventEmitter();
        if (item.validate && item.validate() !== true) {
            result.error(item.validate());
            this.setStatusItem(ResouceEnumStatus.Invalid, 'Error in creating' //translate
            );
            return result;
        }
        if (this.mockedItems !== null) {
            return this.mockCreate(item);
        }
        this.setStatusItem(ResouceEnumStatus.Creating, 'Creating...' //translate
        );
        this.http.post(this.response.getResourceItemUrl(this), item)
            .map(function (response) { return _this.transformModel(_this.response.getResourceItemResponse(_this, response)); })
            .subscribe(function (createdItem) {
            _this.createItem(createdItem);
            result.emit(createdItem);
            _this.setStatusItem(ResouceEnumStatus.Ok);
            _this.setStatusList(ResouceEnumStatus.Ok);
        }, function (error) {
            result.error(UtilsService.extractError(error));
            _this.setStatusItem(ResouceEnumStatus.Invalid, 'Error in creating' //translate
            );
        });
        return result;
    };
    ResourceService.prototype.mockCreate = function (item) {
        var _this = this;
        this.setStatusItem(ResouceEnumStatus.Creating, 'Creating...' //translate
        );
        var result = new EventEmitter();
        setTimeout(function (out) {
            if (item.length) {
                for (var i = 0; i < item.length; i++) {
                    _this.createItem(item[i]);
                }
            }
            else {
                _this.createItem(item);
            }
            result.emit(item);
            _this.setStatusItem(ResouceEnumStatus.Ok);
            _this.setStatusList(ResouceEnumStatus.Ok);
        });
        return result;
    };
    ResourceService.prototype.updateItem = function (updatedItem) {
        var _this = this;
        var founded = false;
        if (this.mockedItems !== null) {
            this.mockedItems.forEach(function (eachItem, i) {
                if (eachItem.pk === updatedItem.pk) {
                    _this.mockedItems[i] = updatedItem;
                    founded = true;
                }
            });
            if (!founded) {
                this.mockedItems.unshift(updatedItem);
            }
            founded = false;
        }
        this.items.forEach(function (eachItem, i) {
            if (eachItem.pk === updatedItem.pk) {
                _this.items[i] = updatedItem;
                founded = true;
            }
        });
        if (!founded) {
            this.calcMeta(this.meta.totalResults + 1);
            this.items.unshift(updatedItem);
        }
        this.items$.next(this.items);
    };
    ResourceService.prototype.update = function (item) {
        var _this = this;
        var result = new EventEmitter();
        if (item.validate() !== true) {
            result.error(item.validate());
            this.setStatusItem(ResouceEnumStatus.Invalid, 'Error in creating' //translate
            );
            return result;
        }
        if (this.mockedItems !== null) {
            return this.mockUpdate(item);
        }
        this.setStatusItem(ResouceEnumStatus.Creating, 'Updating...' //translate
        );
        this.http.put(this.response.getResourceItemUrl(this, item.pk), item)
            .map(function (response) { return _this.transformModel(_this.response.getResourceItemResponse(_this, response)); })
            .subscribe(function (updatedItem) {
            _this.updateItem(updatedItem);
            result.emit(updatedItem);
            _this.setStatusItem(ResouceEnumStatus.Ok);
            _this.setStatusList(ResouceEnumStatus.Ok);
        }, function (error) {
            result.error(UtilsService.extractError(error));
            _this.setStatusItem(ResouceEnumStatus.Invalid, 'Error in updating' //translate
            );
        });
        return result;
    };
    ResourceService.prototype.mockUpdate = function (item) {
        var _this = this;
        this.setStatusItem(ResouceEnumStatus.Creating, 'Updating...' //translate
        );
        var result = new EventEmitter();
        setTimeout(function (out) {
            _this.updateItem(item);
            result.emit(item);
            _this.setStatusItem(ResouceEnumStatus.Ok);
            _this.setStatusList(ResouceEnumStatus.Ok);
        });
        return result;
    };
    ResourceService.prototype.save = function (item) {
        if (item.length === undefined && item.pk) {
            return this.update(item);
        }
        else {
            return this.create(item);
        }
    };
    ResourceService.prototype.removeItems = function (items) {
        var _this = this;
        if (this.mockedItems !== null) {
            var keys_1 = items.map(function (d) { return d.pk; });
            this.mockedItems.forEach(function (t, i) {
                if (keys_1.indexOf(t.pk) !== -1) {
                    _this.mockedItems.splice(i, 1);
                }
            });
        }
        var keys = items.map(function (d) { return d.pk; });
        this.items.forEach(function (t, i) {
            if (keys.indexOf(t.pk) !== -1) {
                _this.items.splice(i, 1);
            }
        });
        if (this.meta.totalResults > 1 && this.items.length === 0) {
            this.meta.curPage = this.meta.curPage - 1;
            this.loadAll();
            return;
        }
        if (this.meta.totalResults < this.meta.perPage && this.meta.curPage > 1) {
            this.meta.curPage = 1;
            this.loadAll();
            return;
        }
        this.calcMeta(this.meta.totalResults - 1);
        this.items$.next(this.items);
    };
    ResourceService.prototype.remove = function (items) {
        var _this = this;
        if (this.mockedItems !== null) {
            return this.mockRemove(items);
        }
        var result = new EventEmitter();
        var ids = items.map(function (d) { return d.pk; });
        this.setStatusItem(ResouceEnumStatus.Creating, 'Removing...' //translate
        );
        this.http.delete(this.response.getResourceItemUrl(this, ids.join('|'))).subscribe(function (response) {
            var prevLength = _this.items.length;
            _this.removeItems(items);
            if (prevLength === 0 && _this.items.length === 0) {
                result.error({
                    error: 'Not found' //translate
                });
                _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                );
            }
            else {
                if (_this.items.length === 0) {
                    result.emit({
                        message: 'OK' //translate
                    });
                    _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                    );
                }
                else {
                    result.emit({
                        message: 'OK' //translate
                    });
                    _this.setStatusItem(ResouceEnumStatus.Ok);
                }
            }
        }, function (error) {
            result.error(UtilsService.extractError(error));
            _this.setStatusItem(ResouceEnumStatus.Invalid, 'Error on deleting' //translate
            );
        });
        return result;
    };
    ResourceService.prototype.mockRemove = function (items) {
        var _this = this;
        this.setStatusItem(ResouceEnumStatus.Creating, 'Removing...' //translate
        );
        var result = new EventEmitter();
        setTimeout(function (out) {
            var prevLength = _this.items.length;
            _this.removeItems(items);
            if (prevLength === 0 && _this.items.length === 0) {
                result.error({
                    error: 'Not found' //translate
                });
                _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                );
            }
            else {
                if (_this.items.length === 0) {
                    result.emit({
                        message: 'OK' //translate
                    });
                    _this.setStatusList(ResouceEnumStatus.NotFound, 'Not found' //translate
                    );
                }
                else {
                    result.emit({
                        message: 'OK' //translate
                    });
                    _this.setStatusItem(ResouceEnumStatus.Ok);
                }
            }
        });
        return result;
    };
    ResourceService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    ResourceService.ctorParameters = function () { return [
        { type: HttpService, },
        { type: ResponseService, },
    ]; };
    return ResourceService;
}());
//# sourceMappingURL=resource.service.js.map